@@ -11,7 +11,6 @@
         command function scope to avoid heavy import on CLI evaluation,
         leading to large bootstraping time.
 """
-
 import json
 from functools import partial
 from glob import glob
@@ -34,6 +33,13 @@ spleeter: Typer = Typer(add_completion=False)
 """ CLI application. """
 
 
+@spleeter.callback()
+def default(
+    version: bool = VersionOption,
+) -> None:
+    pass
+
+
 @spleeter.command()
 def train(
     adapter: str = AudioAdapterOption,
